function getVideoId(input) {
    
    var inputObj;
    try {
        inputObj = JSON.parse(input);
        
        
        var locations = inputObj.locations;
        var locationName = inputObj.locationName;
        var content = inputObj.content;
        var sessionNumber = inputObj.sessionNumber;
        var sessionTime = inputObj.sessionTime;
        var globalTime = inputObj.globalTime;
        var level = inputObj.level;
        
        var currentLocation;
        
        for(var i = 0; i < locations.length; i++){
            if(locations[i].name == locationName){
                currentLocation = locations[i];
            }
        }
        
        if(!currentLocation){
            return {
            show: false,
            reason: 'location ' + locationName + ' is not configured - ' + JSON.stringify(locations),
            code: '101'
            };
        }
        
        var firstDisplayAtSession = 1;
        if(currentLocation.hasOwnProperty('firstDisplayAtSession')){
            firstDisplayAtSession = currentLocation.firstDisplayAtSession;
        }
        if(firstDisplayAtSession > sessionNumber){
            return {
            show: false,
            reason: 'location ' + locationName +
                'has firstDisplayAtSession - ' + firstDisplayAtSession + ' . current session number is - ' + sessionNumber,
            code: '102'
            };
        }
        
        var locationReports = currentLocation.reports;
        
        var showEveryXDisplays = 1;
        if(currentLocation.hasOwnProperty('showEveryXDisplays')){
            showEveryXDisplays = currentLocation.showEveryXDisplays;
        }
        if(locationReports % showEveryXDisplays != 0){
            return {
            show: false,
            reason: 'location ' + locationName +
                ' has reports - ' + locationReports + ' . showEveryXDisplays is - ' + showEveryXDisplays,
            code: '103'
            };
        }
        
        content.sort(function (a, b) {
                     return parseInt(a.priority) - parseInt(b.priority);
                     })
        
        
        
        var locationContentList = currentLocation.contentList;
        
        var selectedContent;
        var latestContent;
        
        var filteredContent = new Array();
        
        for(var i = 0; i < content.length; i++){
            if(!selectedContent){
                for(var j = 0; j < locationContentList.length; j++){
                    if(locationContentList[j] == content[i].videoId){
                    
                        if(content[i].hasOwnProperty('isInstalled') && content[i].isInstalled){
                            continue;
                        }
                        
                        if(!content[i].hasOwnProperty('existsOnDisk') || !content[i].existsOnDisk){
                            continue;
                        }
                        
                        latestContent = content[i];
                        
                        if(!content[i].hasOwnProperty('switchVideo') || !content[i].switchVideo.hasOwnProperty('condition') || !content[i].switchVideo.hasOwnProperty('count')){
                            selectedContent = content[i];
                            filteredContent.push(content[i]);
                            break;
                        }
                        else {
                            if(content[i].switchVideo.condition == 'click'){
                                if(content[i].hasOwnProperty('click')){
                                    if(content[i].switchVideo.count > content[i].click){
                                        selectedContent = content[i];
                                        break;
                                    }
                                    else{
                                        var intVal = Math.floor( content[i].click / content[i].switchVideo.count);
                                        content[i].round = intVal;
                                        filteredContent.push(content[i]);
                                    }
                                }
                                else {
                                    selectedContent = content[i];
                                    break;
                                }
                            }
                            if(content[i].switchVideo.condition == 'display'){
                                if(content[i].hasOwnProperty('display')){
                                    if(content[i].switchVideo.count > content[i].display){
                                        selectedContent = content[i];
                                        break;
                                    }
                                    else{
                                        var intVal = Math.floor( content[i].display / content[i].switchVideo.count);
                                        content[i].round = intVal;
                                        filteredContent.push(content[i]);
                                    }
                                }
                                else {
                                    selectedContent = content[i];
                                    break;
                                }
                            }
                        }
                    }
                }
            }
        }
        
        filteredContent.sort(function (a, b) {
                     return a.round - b.round;
                     })
        
        if (!selectedContent){
            // In case we got here it means that all videoes in the filtered list has conditions and none was met.
            // We need to choose the first one in the filtered array.
            selectedContent = filteredContent[0];
        }
        
        if(!selectedContent){
            selectedContent = latestContent;
        }
        if(!selectedContent){
            return {
                show: false,
            reason: 'could not find a video to show under these conditions.',
            code: '404',
            ariel: filteredContent
          };
        }
        else {
            return {
          show: true,
          videoId: selectedContent.videoId,
          code: '200'
        };
        }
        
        
        
    }
    catch (err) {
        return {
        show: false,
        reason: err.message,
        code: '100'
        };
    }
    
}
